# test.py Copyright (c) 2005,2006 Participatory Culture Foundation
#
# Includes all PyUnit unit tests
#

import unittest

from test.databasetest import *
from test.templatetest import *
from test.fasttypestest import *
from test.schematest import *
from test.storedatabasetest import *
from test.olddatabaseupgradetest import *
from test.databasesanitytest import *
from test.subscriptiontest import *
from test.schedulertest import *
from test.httpclienttest import *
from test.httpdownloadertest import *
from test.feedparsertest import *
from test.parseurltest import *
from test.utiltest import *
from test.playlisttest import *
from test.unicodetest import *
from test.databaseupgradetest import *
import test.bmachinetest
